@@ -64,9 +64,14 @@ class Follow(models.Model):
         return '%s' % self.target
 
     def _get_target(self):
-        for _, fname in model_map.values():
-            if hasattr(self, fname) and getattr(self, fname):
-                return getattr(self, fname)
+        for Model, (_, fname) in model_map.iteritems():
+            try:
+                if hasattr(self, fname) and getattr(self, fname):
+                    return getattr(self, fname)
+            except Model.DoesNotExist:
+                # In case the target was deleted in the previous transaction 
+                # it's already gone from the db and this throws DoesNotExist.
+                return None
     
     def _set_target(self, obj):
         for _, fname in model_map.values():
@@ -83,7 +88,20 @@ def follow_dispatch(sender, instance, created=False, **kwargs):
         followed.send(instance.target.__class__, user=instance.user, target=instance.target, instance=instance)
 
 def unfollow_dispatch(sender, instance, **kwargs):
-    unfollowed.send(instance.target.__class__, user=instance.user, target=instance.target, instance=instance)
+    # FIXME: When deleting out of the admin, django *leaves* the transaction
+    # management after the user is deleted and then starts deleting all the
+    # associated objects. This breaks the unfollow signal. Looking up 
+    # `instance.user` will throw a `DoesNotExist` exception.  The offending
+    # code is in django/db/models/deletion.py#70
+    # At least that's what the error report looks like and I'm a bit short 
+    # on time to investigate properly. 
+    # Unfollow handlers should be aware that both target and user can be `None`
+    try:
+        user = instance.user
+    except User.DoesNotExist:
+        user = None
+    
+    unfollowed.send(instance.target.__class__, user = user, target = instance.target, instance = instance)
     
     
 post_save.connect(follow_dispatch, dispatch_uid='follow.follow_dispatch', sender=Follow)
